@@ -46,7 +46,7 @@
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "1.6.4"
+#define OATH_VERSION "1.8.0"
 
 /**
  * OATH_VERSION_NUMBER
@@ -56,7 +56,7 @@
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x01060400
+#define OATH_VERSION_NUMBER 0x01080000
 
 /**
  * oath_rc:
@@ -119,6 +119,9 @@ extern OATHAPI const char *oath_check_version (const char *req_version);
 
 extern OATHAPI int oath_hex2bin (char *hexstr, char *binstr, size_t * binlen);
 
+extern OATHAPI const char *oath_strerror (int err);
+extern OATHAPI const char *oath_strerror_name (int err);
+
 /* HOTP */
 
 #define OATH_HOTP_LENGTH(digits, checksum) (digits + (checksum ? 1 : 0))
